==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Flokkur");
define("_LVOTES","atkvi");
define("_HITS","Heimsknir");
define("_TOPWELCOME","Velkomin(n)  TOPP suna hj");
define("_READSTORIES","vinslustu frttirnar");
define("_COMMENTEDSTORIES","umtluustu frttirnar");
define("_ACTIVECAT","most active categories");
define("_READSECTION","mest lesnu greinar  greinasafninu");
define("_NEWSSUBMITTERS","virkustu frttaritararnir");
define("_NEWSSENT","innsendar frttir");
define("_VOTEDPOLLS","vinslustu kannanirnar");
define("_MOSTACTIVEAUTHORS","virkustu ritararnir");
define("_NEWSPUBLISHED","innsendar frttir");
define("_READREVIEWS","vinslustu umsagnirnar");
define("_DOWNLOADEDFILES","mest sttu skrrnar");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-6.0.tgz: www/phpnuke/html/modules/Top/language/lang-icelandic.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_CATEGORY","Flokkur");
define("_LVOTES","atkvi");
define("_HITS","Heimsknir");
define("_TOPWELCOME","Velkomin(n)  TOPP suna hj");
define("_READSTORIES","vinslustu frttirnar");
define("_COMMENTEDSTORIES","umtluustu frttirnar");
define("_ACTIVECAT","most active categories");
define("_READSECTION","mest lesnu greinar  greinasafninu");
define("_NEWSSUBMITTERS","virkustu frttaritararnir");
define("_NEWSSENT","innsendar frttir");
define("_VOTEDPOLLS","vinslustu kannanirnar");
define("_MOSTACTIVEAUTHORS","virkustu ritararnir");
define("_NEWSPUBLISHED","innsendar frttir");
define("_READREVIEWS","vinslustu umsagnirnar");
define("_DOWNLOADEDFILES","mest sttu skrrnar");
define("_MOSTREADPAGES","most read pages");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
